aboutsummaryrefslogtreecommitdiffstats
path: root/python_openapi_client/fatcat_openapi_client/models/error_response.py
diff options
context:
space:
mode:
Diffstat (limited to 'python_openapi_client/fatcat_openapi_client/models/error_response.py')
-rw-r--r--python_openapi_client/fatcat_openapi_client/models/error_response.py15
1 files changed, 8 insertions, 7 deletions
diff --git a/python_openapi_client/fatcat_openapi_client/models/error_response.py b/python_openapi_client/fatcat_openapi_client/models/error_response.py
index 7c03b68d..3406c52e 100644
--- a/python_openapi_client/fatcat_openapi_client/models/error_response.py
+++ b/python_openapi_client/fatcat_openapi_client/models/error_response.py
@@ -5,9 +5,9 @@
Fatcat is a scalable, versioned, API-oriented catalog of bibliographic entities and file metadata. # noqa: E501
- OpenAPI spec version: 0.3.1
+ The version of the OpenAPI document: 0.3.1
Contact: webservices@archive.org
- Generated by: https://github.com/swagger-api/swagger-codegen.git
+ Generated by: https://openapi-generator.tech
"""
@@ -18,19 +18,20 @@ import six
class ErrorResponse(object):
- """NOTE: This class is auto generated by the swagger code generator program.
+ """NOTE: This class is auto generated by OpenAPI Generator.
+ Ref: https://openapi-generator.tech
Do not edit the class manually.
"""
"""
Attributes:
swagger_types (dict): The key is attribute name
and the value is attribute type.
attribute_map (dict): The key is attribute name
and the value is json key in definition.
"""
- swagger_types = {
+ openapi_types = {
'success': 'bool',
'error': 'str',
'message': 'str'
@@ -43,7 +44,7 @@ class ErrorResponse(object):
}
def __init__(self, success=None, error=None, message=None): # noqa: E501
- """ErrorResponse - a model defined in Swagger""" # noqa: E501
+ """ErrorResponse - a model defined in OpenAPI""" # noqa: E501
self._success = None
self._error = None
@@ -127,7 +128,7 @@ class ErrorResponse(object):
"""Returns the model properties as a dict"""
result = {}
- for attr, _ in six.iteritems(self.swagger_types):
+ for attr, _ in six.iteritems(self.openapi_types):
value = getattr(self, attr)
if isinstance(value, list):
result[attr] = list(map(
@@ -18,19 +18,20 @@ import six
"""
Attributes:
- swagger_types (dict): The key is attribute name
+ openapi_types (dict): The key is attribute name
and the value is attribute type.
attribute_map (dict): The key is attribute name